%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%How Destructive is Innovation?
%Daniel Garcia-Macia, Chang-Tai Hsieh & Pete Klenow.
%April 2019

%This is the main code to run. It finds the parameters of the exogenous
%innovation process that minimize the distance between simulation and data
%moments. It also computes results for the Polar Models.

%This code calls either the function "error_fun.m" or "main_moments.m",
% which compute errors in target moments given a model specification and
% a set of parameters.

%The plots included in the paper are generated running the file
%"plots_simulation.m".

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

clear all; close all; clc;
tic

%Choose model specification and data sample:
model=5;   %model=1 for CD only with sigma=1, model=3 for OI only, model=4 for CD only with sigma=4, model=5 for Simulation Model    

sample=3; % sample=1 for the 1980's, sample=2 for the 1990's, sample=3 for the 2000's, 
% sample=5 for the 1980's with annual data, sample=6 for the 1990's with annual data, sample=7 for the 2000's with annual data
% sample=8 for VA mfg, sample=9 for TFPQ mfg, 
% sample=10 for ICT 1988, sample=11 for ICT 1998, sample=12 for ICT 2008

robustness=3; % 3 for baseline, 4 for no M&A, 5 for targeted entrants,
% 6 for sigma=3, 7 for sigma=5, 8 for 2/3 small growth cutoff, 9 for 10-year periods

jacobian=0; %whether the code computes the jacobian matrix (set =0 to search for optimal parameters)
%to run jacobian=1, set model=5, robustness=3, sample=3.

%Initialize computational parameters:
max_age = 200/5; %maximum age a firm can achieve (each period is equal to 5 years)
if sample>=5 || sample<=7 %annual data
    max_age = 80;
end
repetitions = 8000; %number of entrant firms in each simulation
iterations = 50; %iterations computed per set of parameters

%% Load data moments:
if robustness==4
    all_data_LBD=xlsread('moments_lbd.xls',4,'d1:d102');
elseif robustness>=6
    all_data_LBD=xlsread('moments_lbd.xls',robustness+7,'d1:d102');
else
    all_data_LBD=xlsread('moments_lbd.xls',sample,'d1:d102');
end

data_mshare=[all_data_LBD(5);1-all_data_LBD(5)]; %employment share for young and for old
data_exit_size_2=all_data_LBD(14:15); %annualized exit above and below mean
data_DHS=all_data_LBD(21:end); %job destruction (JD) and job creation (JC) by firm growth in pct. (Davis-Haltiwanger-Schuh measure)
data_mean_size_v2=all_data_LBD(9); %mean size per firm
data_size_age=all_data_LBD(6:7); %mean size for young and for old
data_creat_dest=all_data_LBD(12:13); %aggregate JD and JC flows
data_std_logsize=all_data_LBD(18:19,1); %standard deviation of log firm size
data_TFP=all_data_LBD(16); %annual TFP growth

gN=-diff(data_creat_dest); %employment growth over 5 years
gY=(1+data_TFP)^5-1+gN; %real output growth over 5 years
if model<5
    gY=(1+data_TFP)^5-1; %real output growth over 5 years
end

%% Initial guess for parameters:

%Initialize model parameters:

%sigma: elasticity of substitution across varieties:
if model==1
    sigma = 1+1e-10; %sum a tiny number to avoid dividing by zero later
else
    sigma=4;
    if robustness==6
        sigma=3;
    elseif robustness==7
        sigma=5;
    end
end

delta_o=0; %fraction of varieties killed by overhead (OH) costs
psi=0; %quality of the threshold variety killed by OH costs relative to the mean
theta=0; %shape parameter of the Pareto distribution for innovation multiplicative-step draws

%Initial guess for parameter vector:
% param_grid_names={'delta_i','delta_e','kappa_i','kappa_e','lambda_i','s_q','rho_e','s_kappa','alpha'}';
% where s_q is the average multiplicative step for creative destruction (CD) and own innovation (OI)
%and s_kappa is the multiplicative step for new varieties.

if model==1 || model==4 %polar models CD-only
    param_grid=[(1-0.283)*(1-.779) 0.283*(1-.779) 0 0 0 1 1 [1 1] 1]';
    lb=[0 0 0 0];ub=[1 1 1 1];   %Bounds for optimization search (just a placeholder here)
    if model==4 %
        psi=0.051; %need psi>0 to avoid an exploding size distribution
    end
    
elseif model==5 %simulation model
    if sample<=2
        delta_o=1e-5;
        psi=0.052;
        param_grid=[1-0.7 0.7 0 gN 0.71 1.0369 1 0.3 1]';
        %Bounds for optimization search:
        lb=[0.5 gN/2 0.5 0.1];ub=[0.95 2*gN 0.9 0.5];
        if sample==2
            param_grid=[1-0.51 0.51 0 gN 0.71 1.0369 1 0.36 1]';
            %Bounds for optimization search:
            lb=[0.4 gN/2 0.5 0.1];ub=[0.95 2*gN 0.9 0.5];
        end
        
    elseif sample>=3
        delta_o=4e-3;
        psi=0.067;
        param_grid=[1-0.66 0.66 gN 0 0.81 1.06 1 psi+0.15 1]';
        if robustness==3
            param_grid=[1-0.8 0.8 0 gN 0.65 1.06 1 0.3 1]';
        elseif robustness==4
            param_grid=[1-0.8 0.8 0 gN 0.65 1.06 1 0.3 1]';
        elseif robustness==5
            param_grid=[1-0.9 0.9 gN 0 0.7 1.06 0.5 0.5 1]';
        elseif robustness==6
            param_grid=[1-0.69 0.69 0 gN 0.6 1.06 1 0.2 1]';
        elseif robustness==7
            param_grid=[1-0.7 0.7 0 gN 0.8 1.06 1 0.5 1]';
        elseif robustness==8
            param_grid=[1-0.8 0.8 0 gN 0.65 1.06 1 0.3 1]';
        elseif robustness==9
            param_grid=[1-0.8 0.8 0 gN 0.65 1.06 1 0.3 1]';
        end
        if sample==5
            param_grid=[1-0.43 0.43 0 gN 0.9 1.02 1 0.37 1]';            
        elseif sample==6
            param_grid=[1-0.75 0.75 0 gN 0.85 1.02 1 0.4 1]';
        elseif sample==7
            param_grid=[1-0.39 0.39 0 gN 0.925 1.02 1 0.35 1]';          
        elseif sample==8
            param_grid=[1-0.8 0.8 0 gN 0.65 1.06 1 0.3 1]';
        elseif sample==9
            param_grid=[1-0.2 0.2 0 gN*1.8 0.45 1.02 1 0.45 1]';
        elseif sample==10
            param_grid=[1-0.78 0.78 0 gN  0.86 1.02 1 2 (1+gY-gN)-0.22]';
        elseif sample==11
            param_grid=[1-0.25 0.75 0 gN  0.78 1.02 1 2 (1+gY-gN)-0.2]';
        elseif sample==12
            param_grid=[1-0.75 0.75 0 gN  0.89 1.02 1 2 (1+gY-gN)-0.25]';
        end
        
        %Bounds for optimization search:
        lb=[0.3 gN/2 0.4 0.1];ub=[0.78 2*gN 0.9 0.7];
        if robustness==3
            lb=[0.7 gN/2 0.4 0.1];ub=[0.99 2*gN 0.9 0.7];
        elseif robustness==4
            lb=[0.7 gN/2 0.4 0.1];ub=[0.99 2*gN 0.9 0.7];
        elseif robustness==5
            lb=[0.7 gN/2 0.4 0.08 0.35];ub=[0.99 3*gN 0.9 0.7 1];
        elseif robustness==6
            lb=[0.6 gN/2 0.4 0.1];ub=[0.99 2*gN 0.9 0.7];
        elseif robustness==7
            lb=[0.6 gN/2 0.4 0.1];ub=[0.99 2*gN 0.9 0.7];
        elseif robustness==8
            lb=[0.7 gN/2 0.4 0.1];ub=[0.99 2*gN 0.9 0.7];
        elseif robustness==9
            lb=[0.7 gN/2 0.4 0.1];ub=[0.99 2*gN 0.9 0.7];
        end
        if sample>=5
            lb=[0.3 gN/2 0.2 0.1];ub=[0.99 2*gN 0.99 0.7];
            if sample==8
                lb=[0.3 gN/2 0.2 0.1];ub=[0.99 2*gN 0.85 0.7];
            elseif sample==10 || sample==12
                lb=[0.3 gN/2 0.2 1 1]; ub=[0.95 2*gN 0.97 9 2];
            elseif sample==11
                lb=[0.3 gN/2 0.2 psi*29 2.5]; ub=[0.95 2*gN 0.97 15 4];
            elseif sample==8 ||sample==9
                lb=[0 gN/2 0.2 0.1];ub=[1 2*gN 0.99 0.7];
            end
        end
    end
end

if model==1 || model>3 %for Polar Models NV-only and OI-only, jump to last block of code
    
    %Load initial guess for the geometric quality distribution, i.e. quality^(sigma-1)
    if model==1
        qualpowerstore_vec_guess=ones(10,1); %quality distribution is irrelevant when sigma=1
    elseif model==4
        load initial_guess_v106_1.mat;
    elseif model==5
        if sample<3
            load initial_guess_v106_1.mat;
        elseif sample>=3
            load initial_guess_v106_2.mat;
            if robustness==4 || robustness==5
                load initial_guess_rhoe_small.mat;
            end
        end
        if sample==8 || sample==9
            load initial_guess_s8.mat
        end
    end
       
    %% Optimization loop
    %Compute error in moments and iterate parameters
    
    %Load initial parameters
    param_init=param_grid([2 4 5 8]);
    if robustness==5
        param_init=param_grid([2:3 5 8 7]);
    end
    if sample>=10
        param_init=param_grid([2 4 5 8 9]);
    end

    %Search optimal values
    if jacobian==0
        if model==5
            options = optimset('Display','iter');
            [params_optim,errorval,exitflag,output]=fminsearch(@(params) error_fun(params,sigma,max_age,repetitions,gY,qualpowerstore_vec_guess,model,psi,delta_o,data_mean_size_v2,iterations,...
                data_DHS,data_mshare,data_creat_dest,gN,data_std_logsize,robustness,data_size_age,data_exit_size_2,ub,lb,jacobian,sample),...
                param_init,options);
        else
            params_optim=param_grid([1 2 5 8]); %parameters are given for the polar models
        end
        %recover moment values for the optimized parameters
        [error,param_grid,delta_o,psi,exit_age5_grid,mshare_age5_grid,...
            aver_size_age5,aver_size_model_grid,min_size_grid,...
            creat_dest_grid,exit_size2_level_grid,std_logsize_grid,...
            growth_halt_grid,variety_vec_corrected_store,contrib_growth_age_grid,JC_age_corrected_grid,JD_age_corrected_grid,exit_size500_level_grid,psi_mean]...
            =error_fun(params_optim,sigma,max_age,repetitions,gY,qualpowerstore_vec_guess,model,psi,delta_o,data_mean_size_v2,iterations,...
            data_DHS,data_mshare,data_creat_dest,gN,data_std_logsize,robustness,data_size_age,data_exit_size_2,ub,lb,jacobian,sample);
        
    else %parameters are given for the Jacobian
        param_grid_opt_read=xlsread('sim_results',4,'e2:e11');
        param_grid_opt=[param_grid_opt_read([1:5 8 10 9]); 1];
        %step for the numerical derivative
        jac_step=[zeros(8,1) [-0.01; zeros(7,1)] [0; -0.01; zeros(6,1)] [0;0; 0.005; zeros(5,1)] [0;0;0; 0.005; zeros(4,1)] [zeros(4,1); -0.02; 0;0;0] [zeros(6,1); -0.02; 0] [zeros(7,1); 0.02]];
        param_jac=repmat(param_grid_opt,1,8)+[jac_step; zeros(1,8)];
        moments_jac=zeros(9,length(param_grid_opt)-1);
        
        for i=1:length(param_grid_opt)-1 %calculate moments for deviations in each parameter 
            param_grid=param_jac(:,i);
            
            sq_grid = (((1+gY-gN).^(sigma-1)+delta_o*(psi-param_grid(8,:))-param_grid(3,:).*param_grid(8,:)-param_grid(4,:).*param_grid(8,:)-1+param_grid(5,:)+(1-param_grid(5,:)).*(param_grid(1,:)+param_grid(2,:).*param_grid(7,:)))./...
                ((param_grid(5,:)+(1-param_grid(5,:)).*param_grid(1,:))+param_grid(7,:).*param_grid(2,:).*(1-param_grid(5,:)))).^(1/(sigma-1)); %see TFP growth formula in the paper
            param_grid(6,:)=sq_grid;

            [error,~,~,~,~,mshare_age5_grid,...
                aver_size_age5,aver_size_model_grid,min_size_grid,...
                creat_dest_grid,exit_size2_level_grid,std_logsize_grid,...
                growth_halt_grid]...
                =error_fun(param_grid,sigma,max_age,repetitions,gY,qualpowerstore_vec_guess,model,psi,delta_o,data_mean_size_v2,iterations,...
                data_DHS,data_mshare,data_creat_dest,gN,data_std_logsize,robustness,data_size_age,data_exit_size_2,ub,lb,jacobian,sample);
            
            %store moments
            moments_jac(:,i)=[mean(data_mean_size_v2*aver_size_age5(:,5:end)./repmat(aver_size_model_grid(:,5:end),2,1),2);...
                mean(mshare_age5_grid(1,5:end),2);...
                mean(creat_dest_grid(:,5:end),2);...
                mean(std_logsize_grid(:,5:end));...
                mean(sum(growth_halt_grid(42:61,5:end))./sum(growth_halt_grid(42:end,5:end)));...
                mean(exit_size2_level_grid(:,5:end),2)];
        end
        
        %Calculate numerical derivative (Jacobian):
        Jac=(moments_jac(:,2:end)-repmat(moments_jac(:,1),1,length(param_grid)-2))./repmat(sum(jac_step(:,2:end)),length(moments_jac(:,1)),1);
        
        varcov_data_lowdiag=xlsread('jacobian.xls','varcov data','b2:j10'); %load varcovar matrix in data
        varcov_data=varcov_data_lowdiag;
        for i=1:size(varcov_data_lowdiag,1) %create full var-covar matrix
            for j=1:size(varcov_data_lowdiag,2)
                if j>i
                    varcov_data(i,j)=varcov_data_lowdiag(j,i);
                end
            end
        end
        Jac_short=Jac(:,[1 4 5 end]); %Jacobian for unconstrained parameters
%         Weights used in the optimization:
        weighting_mat=diag([0.5 0.5 1 1 1 1 1 0.5 0.5]).*diag(1./[data_size_age;data_mshare(1);data_creat_dest;data_std_logsize(2);sum(data_DHS(42:61))./sum(data_DHS(42:end));data_exit_size_2].^2);
        %Varcovar matrix, without accounting for error in simulation moments:
        varcov_params=inv(Jac_short'*weighting_mat*Jac_short)*...
            Jac_short'*weighting_mat*varcov_data*weighting_mat*Jac_short*...
            inv(Jac_short'*weighting_mat*Jac_short);
        se_params=sqrt(diag(varcov_params)); %standard error of parameters
        
        xlswrite('jacobian.xls',Jac,1,'b2');
        xlswrite('jacobian.xls',se_params,3,'c2');
                
        %compute standard error in simulation moments by Monte Carlo
        reps_MC=200;
        param_grid=param_jac(:,1);
        sq_grid = (((1+gY-gN).^(sigma-1)+delta_o*(psi-param_grid(8,:))-param_grid(3,:).*param_grid(8,:)-param_grid(4,:).*param_grid(8,:)-1+param_grid(5,:)+(1-param_grid(5,:)).*(param_grid(1,:)+param_grid(2,:).*param_grid(7,:)))./...
            ((param_grid(5,:)+(1-param_grid(5,:)).*param_grid(1,:))+param_grid(7,:).*param_grid(2,:).*(1-param_grid(5,:)))).^(1/(sigma-1)); %see TFP growth formula in the paper
        param_grid(6,:)=sq_grid;
        moments_simse=zeros(9,reps_MC);
        for i=1:reps_MC %draw many samples with a different random number generator each time
            [error,~,~,~,~,mshare_age5_grid,...
                aver_size_age5,aver_size_model_grid,min_size_grid,...
                creat_dest_grid,exit_size2_level_grid,...
                std_logsize_grid,growth_halt_grid]...
                =error_fun(param_grid,sigma,max_age,repetitions,gY,qualpowerstore_vec_guess,model,psi,delta_o,data_mean_size_v2,iterations,...
                data_DHS,data_mshare,data_creat_dest,gN,data_std_logsize,robustness,data_size_age,data_exit_size_2,ub,lb,i,sample);
            
            moments_simse(:,i)=[mean(data_mean_size_v2*aver_size_age5(:,5:end)./repmat(aver_size_model_grid(:,5:end),2,1),2);...
                mean(mshare_age5_grid(1,5:end),2);...
                mean(creat_dest_grid(:,5:end),2);...
                mean(std_logsize_grid(:,5:end));...
                mean(sum(growth_halt_grid(42:61,5:end))./sum(growth_halt_grid(42:end,5:end)));...
                mean(exit_size2_level_grid(:,5:end),2)];
        end
        moments_simse_vcov=(moments_simse-repmat(mean(moments_simse,2),1,reps_MC))*(moments_simse-repmat(mean(moments_simse,2),1,reps_MC))'/reps_MC; %calculate varcov matrix of simualted moments
        varcov_params_full=varcov_params+inv(Jac_short'*weighting_mat*Jac_short)*...
            Jac_short'*weighting_mat*(moments_simse_vcov)*weighting_mat*Jac_short*...
            inv(Jac_short'*weighting_mat*Jac_short); %add moment simulation error component to varcov matrix of parameters
        se_params_full=sqrt(diag(varcov_params_full));
        xlswrite('jacobian.xls',se_params_full,4,'c2');
    end
    
    
    %% Calculate remaining moments for simulation
    if jacobian==0
        psi=psi_mean;
        %Obtaining s_q (average multiplicative step size) to fit TFP growth
        if model==1 || model==4 %polar models
            theta=17.3408902532029; %theta from simulation used for polar models
            sq_grid=theta/(theta-sigma+1);
            param_grid(6,:)=sq_grid;
        else
            sq_grid = param_grid(6,:);
            theta=((1-sigma)*sq_grid.^(sigma-1))./(param_grid(9,:).^(sigma-1)-sq_grid.^(sigma-1)); %theta consistent with average step size equal to s_q
        end
        
        % Contributions by each innovation channel: (compute contribution to growth
        % of each channel assuming that the rest of channels are zero)
        
        % contrib_names={'creative destruction by incumbents', 'creative destruction by entrants', 'new varieties by incumbents','new varieties by entrants', 'own innovation by incumbents','OH cost new varieties'};
        contributions=[(sq_grid.^(sigma-1)).*(1-param_grid(5,:)).*param_grid(1,:)+(1-(1-param_grid(5,:)).*param_grid(1,:));...
            (sq_grid.^(sigma-1)).*(1-param_grid(5,:)).*param_grid(2,:).*param_grid(7,:)+(1-(1-param_grid(5,:)).*param_grid(2,:).*param_grid(7,:));...
            param_grid(8,:).*param_grid(3,:)+1;...
            param_grid(8,:).*param_grid(4,:)+1;...
            (sq_grid.^(sigma-1)).*param_grid(5,:)+1-param_grid(5,:);...
            param_grid(8,:)*delta_o+1-delta_o*psi].^(1/(sigma-1))-1; %approximation assuming initial share of OH varieties is given by psi
        contributions_norm=100*contributions./repmat(sum(contributions,1),size(contributions,1),1); %normalize to 100 percent
        contributions_norm(4)=contributions_norm(4)+contributions_norm(end); %varieties replaced due to OH cost are also new varieties by entrants
        
        if model==1
            contributions_norm=[param_grid(1:2,:)./repmat(sum(param_grid(1:2,:)),2,1); zeros(3,1)];
            param_grid(end-3,:)=sq_grid;
        end
        
        %contribution to employment growth by small growers
        if robustness~=8
            small_growth=100*sum(growth_halt_grid(42:61,:))./sum(growth_halt_grid(42:end,:));
            data_small_growth=sum(data_DHS(42:61,:));
        else
            small_growth=100*sum(growth_halt_grid(42:54,:))./sum(growth_halt_grid(42:end,:));
            data_small_growth=sum(data_DHS(42:54,:));
        end
        
        
        %distribution of num of varieties
        un_vals_vars=unique(variety_vec_corrected_store);
        hist_vars=zeros(1,max(un_vals_vars));
        for i=1:length(un_vals_vars)
            hist_vars(i)=mean(variety_vec_corrected_store==un_vals_vars(i));
        end
        hist_vars_tab=[[1:max(un_vals_vars)]' 100*hist_vars'];
        
        %Contribution to growth, JC and JD by age
        contrib_growth_age_mean=mean(contrib_growth_age_grid,2)/sum(mean(contrib_growth_age_grid,2));
        JC_age_mean=mean(JC_age_corrected_grid,2)/sum(mean(JC_age_corrected_grid,2));
        JD_age_mean=mean(JD_age_corrected_grid,2)/sum(mean(JD_age_corrected_grid,2));
        if sample<5 || sample>7
            contrib_growth_age_short=[contrib_growth_age_mean(1:3);sum(contrib_growth_age_mean(4:end))];
            JC_age_short=[];
            JD_age_short=[];
        else
            contrib_growth_age_short=[sum(contrib_growth_age_mean(1:5));sum(contrib_growth_age_mean(6:10));...
                sum(contrib_growth_age_mean(11:15));sum(contrib_growth_age_mean(16:end))];
            JC_age_short=[sum(JC_age_mean(1:5));sum(JC_age_mean(6:10));...
                sum(JC_age_mean(11:15));sum(JC_age_mean(16:end))];
            JD_age_short=[sum(JD_age_mean(1:5));sum(JD_age_mean(6:10));...
                sum(JD_age_mean(11:15));sum(JD_age_mean(16:end))];
        end  
        
        % Store optimized parameters and associated moments to save in excel:
        if sample>=10
            param_grid(7)=param_grid(9);
        end
        Table_simulated_moments=[repmat([param_grid(1:3,:);param_grid(4,:)+delta_o;param_grid(5,:);delta_o;...
            theta;param_grid([6; 8; 7],:);psi;contributions_norm],1,iterations);...
            mshare_age5_grid(1,:); data_mean_size_v2*aver_size_age5./repmat(aver_size_model_grid,2,1); min_size_grid;data_mean_size_v2*ones(1,iterations);small_growth/100;...
            creat_dest_grid; [exit_size2_level_grid];((1+gY-gN)^(0.2)-1)*ones(1,iterations);((1+param_grid(3,:)+param_grid(4,:)).^(0.2)-1)*ones(1,iterations);std_logsize_grid;...
            [repmat(creat_dest_grid(2,:),41,1);repmat(creat_dest_grid(1,:),41,1)].*growth_halt_grid/100];   
        
        %saving results in Excel:
        if  jacobian==0 && model==5
            if robustness==3
                if sample<5
                    xlswrite('sim_results.xls',[nanmean(Table_simulated_moments(1:17,:),2);...
                        error;nanmean(Table_simulated_moments(18:end,:),2);hist_vars_tab(1:5,2);contrib_growth_age_short;JC_age_short;JD_age_short],sample+1,'e2');
                else
                    xlswrite('sim_results.xls',[nanmean(Table_simulated_moments(1:17,:),2);...
                        error;nanmean(Table_simulated_moments(18:end,:),2);[hist_vars_tab(1:3,2);0;0];contrib_growth_age_short;JC_age_short;JD_age_short],sample+1,'e2');
                end
            elseif robustness==5
                xlswrite('sim_results.xls',[nanmean(Table_simulated_moments(1:17,:),2);...
                    error;nanmean(Table_simulated_moments(18:end,:),2)],sample+1,'f2');
            elseif robustness>=6
                xlswrite('sim_results.xls',results,14+(robustness-6),'h2');
            elseif robustness==4
                xlswrite('sim_results.xls',[nanmean(Table_simulated_moments(1:17,:),2);...
                    error;nanmean(Table_simulated_moments(18:end,:),2)],5,'e2');
            end
        end
    end
end

%% Polar Models: save moments of interest
if model<5
    
    if model==1
        polar1_moments=[mean(exit_age5_grid,2)];
        save polar1_moments polar1_moments
        size_age5_grid=data_mean_size_v2*aver_size_age5./repmat(aver_size_model_grid,2,1);
        save polar1_moments_data_plot exit_age5_grid size_age5_grid creat_dest_grid growth_halt_grid
    end
    
    theta=17.3408902532029; %theta from simulation
    sq=theta/(theta-sigma+1);
    params2=[0 0 [1 1]*0.5*gN 0 (((1+(1+data_TFP)^5-1).^(sigma-1)-1)./(gN)).^(1/(sigma-1))];
    params3=[0 0 0 0 1 sq];
    
    
    %for polar model 3: compute job flows analytically
    if model==3
        step_dest=1/sq-1; %relative power quality step of firms NOT innovating
        rand_draws_creat=sort((1-rand(floor(params3(5)*1e6),1)).^(-(sigma-1)/theta)/sq)-1;
        growthlag_vec=2*rand_draws_creat./(rand_draws_creat+2);
        jobchangelag_vec=rand_draws_creat;
        JC_rate=2*sum(subplus(jobchangelag_vec))/(2e6+sum(subplus(jobchangelag_vec)));
        bins_halt=-2.05:0.05:2.05; %employment growth bins
        growth_halt=[];
        for i=1:length(bins_halt)-1 %compute contribution to JD and JC of each bin
            if i==2
                growth_halt=[growth_halt; sum(abs(jobchangelag_vec(logical((growthlag_vec>bins_halt(i)).*(growthlag_vec<bins_halt(i+1))))))];
            else
                growth_halt=[growth_halt; sum(abs(jobchangelag_vec(logical((growthlag_vec>=bins_halt(i)).*(growthlag_vec<bins_halt(i+1))))))];
            end
        end
        %normalize to JCJD levels%:
        growth_haltabs_grid=2*100*JC_rate*growth_halt./repmat(sum(growth_halt),length(growth_halt),1);
        bar(bins_halt(1:end-1),growth_haltabs_grid)
        
        save polar3_moments_data_plot growth_haltabs_grid
    end
    
    %Save polar model parameters in Excel
    if model==4 %do when running model=4 to back out s_q to match TFP growth
        gY=(1+data_TFP)^5-1; %TFP growth over 5 years
        params_polar=[[(1-0.283)*(1-.779) 0.283*(1-.779) 0 0 0 sq];...
            params2;...
            params3;...
            param_grid([1:5 6])'];
        xlswrite('params_polar.xlsx',params_polar',1,'c4');
        
        %save moment results for plots
        exit_size_KK3=mean([exit_size500_level_grid;NaN*zeros(2,iterations)],2);
        growth_haltabs_KK3=mean(growth_halt_grid,2);
        JDJC_KK3=mean(creat_dest_grid,2); %mean of JD and JC
        %absolute JD and JC:
        JDJCrate_KK3=[JDJC_KK3(2)*ones(length(growth_haltabs_KK3)/2,1);JDJC_KK3(1)*ones(length(growth_haltabs_KK3)/2,1)].*growth_haltabs_KK3;
        save polar_KK3 exit_size_KK3 growth_haltabs_KK3 JDJCrate_KK3 JDJC_KK3
    end
    
end
