%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%How Destructive is Innovation?
%Daniel Garcia-Macia, Chang-Tai Hsieh & Pete Klenow.
%April 2019

%This function simulates relevant moments given a set of parameters and a
%model specification. For each entrant firm, it simulates a life cycle by
%drawing random innovation shocks. Then, it aggregates over all simulated
%firms of different ages, taking into account aggregate employment growth
%over time.

%The working assumption is that all firms (of different ages) generated
%by the simulation of life cycles are contemporary to each other. Hence,
%the code needs to correct for the fact that, with employment growth, older firms
%are overrepresented in the simulation. This is because older firms were
%born at a time when the labor force was smaller, so their share has to be
%downweighted accordingly.

%Legend:
% CD = creative destruction
% OI = own innovation
% NV = creation of new varieties
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


function [mshare_5,aver_size_age5,qualpowerstore_vec,variety_vec_corrected,size_vec,...
    growth_halt,OH_killed_ent,OH_killed_inc,exit_age,exit_size2_level,...
    createt_dest,aver_size_model,std_logsize,delta_i,...
    contrib_growth_age_corrected,JC_age_corrected,JD_age_corrected,exit_size500_level,psi_mean]...
    =moments_fun(sigma,parameters_innov,max_age,repetitions,qualpowerstore_vec_guess,model,psi,delta_o,data_mean_size_v2,robustness)

tic
%Define parameters:
delta_i = parameters_innov(1);  %probability of CD by incumbents
delta_e = parameters_innov(2);  %probability of CD by entrants
kappa_i = parameters_innov(3);  %probability of NV by incumbents
kappa_e = parameters_innov(4);  %probability of NV by entrants (equal to kappa_e-delta_o in the paper)
lambda_i = parameters_innov(5); %probability of OI by incumbents
sq       = parameters_innov(6); %average multiplicative step size of CD and OI
rho_e    = parameters_innov(7); %relative average size of entrants
s_kappa  = parameters_innov(8); %multiplicative step size of NV by incumbents
alpha    = parameters_innov(9); %Pareto scale parameter

%Recover step size
if model==1
    so=1;
else
    so=sq;
    theta=(1-sigma)*so^(sigma-1)/(alpha^(sigma-1)-so^(sigma-1)); %Pareto shape parameter
end

%Compute growth in geometric quality per period (see growth formula in
%the paper)
gqpower = (s_kappa.*parameters_innov(3,:)+s_kappa.*parameters_innov(4,:)+(s_kappa-psi).*delta_o+...
    (1+(so.^(sigma-1)-1).*parameters_innov(5,:)+(1-parameters_innov(5,:)).*((sq.^(sigma-1)-1).*parameters_innov(1,:)+(sq.^(sigma-1)-1).*parameters_innov(2,:)*rho_e)))./...
    (1+parameters_innov(3,:)+parameters_innov(4,:))-1;

%Redefine computational parameters:
N       = max_age; %size of the grid
reps    = repetitions; %Number of paths simulated


%Probabilities of each state in the multinomial distribution of innovation
%shocks.
% Variable definitions (possible outcomes in each period):
% p201: 1 variety created, 1 variety stolen, initial variety improved
% p200: 1 variety created, 1 variety stolen, initial variety NOT improved
% p21: 1 variety created, 1 variety stolen, initial variety lost
% p1101: 1 variety stolen, initial variety improved
% p1100: 1 variety stolen, initial variety NOT improved
% p111: 1 variety stolen, initial variety lost
% p1001: 1 variety created, initial variety improved
% p1000: 1 variety created, initial variety NOT improved
% p101: 1 variety created, initial variety lost
% p001: initial variety improved
% p000: initial variety NOT improved
% p01: initial variety lost

p201=lambda_i*delta_i*kappa_i*(1-lambda_i);
p200=(1-lambda_i)^2*(1-delta_i-delta_e)*delta_i*kappa_i;
p21=(1-lambda_i)^2*(delta_i+delta_e)*delta_i*kappa_i;
p1101=lambda_i*delta_i*(1-kappa_i)*(1-lambda_i);
p1100=(1-lambda_i)^2*(1-delta_i-delta_e)*delta_i*(1-kappa_i);
p111=(1-lambda_i)^2*(delta_i+delta_e)*delta_i*(1-kappa_i);
p1001=lambda_i*kappa_i*(1-delta_i*(1-lambda_i));
p1000=(1-lambda_i)*(1-delta_i-delta_e)*kappa_i*(1-delta_i*(1-lambda_i));
p101=(1-lambda_i)*(delta_i+delta_e)*kappa_i*(1-delta_i*(1-lambda_i));
p001=lambda_i*(1-(delta_i*(1-lambda_i)*(1-kappa_i)+kappa_i*(1-delta_i*(1-lambda_i))+kappa_i*delta_i*(1-lambda_i)));
p000=(1-lambda_i)*(1-delta_i-delta_e)*(1-(delta_i*(1-lambda_i)*(1-kappa_i)+kappa_i*(1-delta_i*(1-lambda_i))+kappa_i*delta_i*(1-lambda_i)));
p01=(1-lambda_i)*(delta_i+delta_e)*(1-(delta_i*(1-lambda_i)*(1-kappa_i)+kappa_i*(1-delta_i*(1-lambda_i))+kappa_i*delta_i*(1-lambda_i)));

p_vec = max([p201 p200 p21 p1101 p1100 p111 p1001 p1000 p101 p001 p000 p01]',0); %bind at zero because Matlab outputs a negative number for 1-(0.2+0.8)

%% Initialization

%Initialize variables to store results

%Density of firms of a given age (rows) and number of varieties (columns)
% (not conditional on survival)
dens_grid = zeros(N,4*N); %firms can at most triple the number of varieties every period
dens_grid(1,1) = reps; %all firms visit first grid point when they enter

%Sum of geometric qualities of a firm (proportional to employment)
qualpower_grid = zeros(N,4*N);

%%Employment share of the following groups:
%Entrants, Exiters, Incumbents up and Incumbents down.
%The first column is the current employment and the second the new one. The
%flow is the difference between the two columns.
employment = zeros(4,2); %employment of a firm is directly proportional to market share or revenue

qualpowerstore_vec=[]; %quality distribution
size_vec=[]; %size distribution
growthlag_vec=[]; %growth distribution (computed a la Haltiwanger)
jobchangelag_vec=[]; %job flows
size_last=[]; %size in the previous period
exit1yr_vec=[]; %vector capturing which firms exit
varietyall_vec=[]; %distribution of teh num. of varieties
OH_killed_ent=[]; %vector of potential (!) entrant varieties killed
OH_killed_inc=[]; %vector of incumbent varieties killed (should be empty)
age_vec=[]; %vector with age of each firm
age_vecall=[]; %vector with age of each firm, including exiters
age_vec_last=[]; %vector with age in the previous period
age_var_vec=[]; %vector with age of each variety

% Contributions to growth ,JC and JD by age:
contrib_growth_age=zeros(N,1);
JC_age=zeros(N,1);
JD_age=zeros(N,1);

%useful variables
sorted_quals=sort(qualpowerstore_vec_guess);
length_quals=length(qualpowerstore_vec_guess);

%For directed entrants model:
% find threshold quality above which entrants can't target varieties
% consistent with average (geometric) relative quality of entrants rho_e
bound_e=find(cumsum(sorted_quals)./((1:length(sorted_quals))'*mean(sorted_quals))>=rho_e,1)-1;
if isempty(bound_e) || robustness~=5
    bound_e=length_quals; %untargeted entry case
end
quals_ent=sorted_quals(1:bound_e); %distribution of qualities targeted
thresh_qual=sorted_quals(bound_e); %max quality targeted
if rho_e==1
    thresh_qual=1e30;
end

delta_e_lowq=min(delta_e*length(sorted_quals)/bound_e,1); %probability of CD by entrants at low qualities
if delta_e_lowq+delta_i>1
    display('error: raise rho_e') %make sure this does not occur with final parameters
    delta_i=1-delta_e_lowq %to continue parameter iteration
end

%transition probabilities below and above threshold quality
%below:
p201=lambda_i*delta_i*kappa_i*(1-lambda_i);
p200=(1-lambda_i)^2*(1-delta_i-delta_e_lowq)*delta_i*kappa_i;
p21=(1-lambda_i)^2*(delta_i+delta_e_lowq)*delta_i*kappa_i;
p1101=lambda_i*delta_i*(1-kappa_i)*(1-lambda_i);
p1100=(1-lambda_i)^2*(1-delta_i-delta_e_lowq)*delta_i*(1-kappa_i);
p111=(1-lambda_i)^2*(delta_i+delta_e_lowq)*delta_i*(1-kappa_i);
p1001=lambda_i*kappa_i*(1-delta_i*(1-lambda_i));
p1000=(1-lambda_i)*(1-delta_i-delta_e_lowq)*kappa_i*(1-delta_i*(1-lambda_i));
p101=(1-lambda_i)*(delta_i+delta_e_lowq)*kappa_i*(1-delta_i*(1-lambda_i));
p001=lambda_i*(1-(delta_i*(1-lambda_i)*(1-kappa_i)+kappa_i*(1-delta_i*(1-lambda_i))+kappa_i*delta_i*(1-lambda_i)));
p000=(1-lambda_i)*(1-delta_i-delta_e_lowq)*(1-(delta_i*(1-lambda_i)*(1-kappa_i)+kappa_i*(1-delta_i*(1-lambda_i))+kappa_i*delta_i*(1-lambda_i)));
p01=(1-lambda_i)*(delta_i+delta_e_lowq)*(1-(delta_i*(1-lambda_i)*(1-kappa_i)+kappa_i*(1-delta_i*(1-lambda_i))+kappa_i*delta_i*(1-lambda_i)));
p_vec_lowq = max([p201 p200 p21 p1101 p1100 p111 p1001 p1000 p101 p001 p000 p01]',0); %bind at zero because Matlab outputs a negative number for 1-(0.2+0.8)

%  above:
delta_e_highq=0;
p201=lambda_i*delta_i*kappa_i*(1-lambda_i);
p200=(1-lambda_i)^2*(1-delta_i-delta_e_highq)*delta_i*kappa_i;
p21=(1-lambda_i)^2*(delta_i+delta_e_highq)*delta_i*kappa_i;
p1101=lambda_i*delta_i*(1-kappa_i)*(1-lambda_i);
p1100=(1-lambda_i)^2*(1-delta_i-delta_e_highq)*delta_i*(1-kappa_i);
p111=(1-lambda_i)^2*(delta_i+delta_e_highq)*delta_i*(1-kappa_i);
p1001=lambda_i*kappa_i*(1-delta_i*(1-lambda_i));
p1000=(1-lambda_i)*(1-delta_i-delta_e_highq)*kappa_i*(1-delta_i*(1-lambda_i));
p101=(1-lambda_i)*(delta_i+delta_e_highq)*kappa_i*(1-delta_i*(1-lambda_i));
p001=lambda_i*(1-(delta_i*(1-lambda_i)*(1-kappa_i)+kappa_i*(1-delta_i*(1-lambda_i))+kappa_i*delta_i*(1-lambda_i)));
p000=(1-lambda_i)*(1-delta_i-delta_e_highq)*(1-(delta_i*(1-lambda_i)*(1-kappa_i)+kappa_i*(1-delta_i*(1-lambda_i))+kappa_i*delta_i*(1-lambda_i)));
p01=(1-lambda_i)*(delta_i+delta_e_highq)*(1-(delta_i*(1-lambda_i)*(1-kappa_i)+kappa_i*(1-delta_i*(1-lambda_i))+kappa_i*delta_i*(1-lambda_i)));
p_vec_highq = max([p201 p200 p21 p1101 p1100 p111 p1001 p1000 p101 p001 p000 p01]',0); %bind at zero because Matlab outputs a negative number for 1-(0.2+0.8)

%For new varieties: find rescaling factor kappa_resc such that the
%mean quality of new varieties surviving the OH costs threshold is s_kappa

psi_abs=psi*mean(qualpowerstore_vec_guess); %absolute quality of the variety at the OH threshold
if s_kappa~=1
    
    %keep searching in a finer grid until error is small
    [kappa_resc,error,EXITFLAG] =fsolve(@(x) s_kappa/(1+gqpower)-x*mean(sorted_quals(sorted_quals>=min(psi_abs/x,max(sorted_quals)))),s_kappa/500);
    if error>5e-4
        [kappa_resc,error,EXITFLAG] =fsolve(@(x) s_kappa/(1+gqpower)-x*mean(sorted_quals(sorted_quals>=min(psi_abs/x,max(sorted_quals)))),s_kappa/50);
        if error>5e-4
            [kappa_resc,error,EXITFLAG] =fsolve(@(x) s_kappa/(1+gqpower)-x*mean(sorted_quals(sorted_quals>=min(psi_abs/x,max(sorted_quals)))),s_kappa/5);
        end
    end
    
    error1=error
    kappa_resc
    EXITFLAG
    
    %number of entrants via new varieties
    new_entrants_num=reps-floor(reps*delta_e*(1-lambda_i)/(delta_e*(1-lambda_i)+kappa_e+delta_o));
    %save eligible qualities of entrant new varieties, i.e., those qualities
    %above the OH threshold, after applying rescaling with kappa_resc<1:
    pool_new_var=sorted_quals(sorted_quals>=(psi_abs/kappa_resc));
    length_pool_new_var=length(pool_new_var);
    
    if kappa_resc>0 && length_pool_new_var==0 %rho_e is too small for entrants to survive OH cost
        display('length_pool_new_var==0')
        error
        pool_new_var=max(sorted_quals); %assume entrants can only target the top quality
        length_pool_new_var=1;
        kappa_resc=psi_abs/max(sorted_quals);
    end
    
    %draw ranmdom qualities of entrant new varieties
    if length_pool_new_var>0
        new_var_entrants=kappa_resc*pool_new_var(unidrnd(length_pool_new_var,new_entrants_num+1,1));
    end
    
else
    length_pool_new_var=0;
    kappa_resc=(sq^(sigma-1))/(1+gqpower);
    new_entrants_num=-1;
end

%useful variable definitions to speed up the loop
sq_rel=(sq^(sigma-1))/(1+gqpower); %relative geometric step size of CD
so_sigma=(so^(sigma-1)); %geometric step size of OI

%% Simulation

rep=0; %initialize first entrant

while rep<reps %simulate life cycle for each entrant
    
    exit=0; %indicates if firm has lost all varieties
    n_current=1; %number of current varieties
    age=1; %iteration count
    
    %be consistent with rate of NV entrants versus CD entrants:
    if rep<=new_entrants_num 
        qualpower_portfolio=new_var_entrants(rep+1); %draw a NV
        contrib_growth=qualpower_portfolio*(1+gqpower); %contribution to growth
    else
        if model>1 %add stochastic step size
            sq_rel=alpha^(sigma-1)*(1-rand)^(-(sigma-1)/theta)/(1+gqpower); %draw from Pareto(theta) to the power of sigma-1
        end
        qualpower_portfolio=sq_rel*quals_ent(unidrnd(bound_e)); %draw a quality and apply CD step
        contrib_growth=qualpower_portfolio*(sq_rel*(1+gqpower)-1)/sq_rel; %contribution to growth
    end
    
    if qualpower_portfolio<psi_abs %drawn quality is below OH threshold
        OH_killed_ent=[OH_killed_ent; qualpower_portfolio]; %record potential entrants that never entered
        rep=rep+1;
    else
        contrib_growth_age(1)=contrib_growth_age(1)+contrib_growth; %contribution to growth by age
        qualpower_total_current=qualpower_portfolio; %geometric sum of qualities of a firm
        emp_current=qualpower_portfolio; %employment of a firm (up to a proportionality constant)
        contrib_growth=qualpower_portfolio;
        JC_age(1)=JC_age(1)+qualpower_portfolio; %add to JC by entrants
        
        varietyall_vec=[varietyall_vec 1]; %record number of varieties
        age_vec=[age_vec 1]; %record firm age for survivors
        age_vecall=[age_vecall 1]; %record firm age for all firms, including exiters
        age_var_vec=[age_var_vec; 1]; %record age for each variety
        
        
        qualpowerstore_vec=[qualpowerstore_vec; qualpower_portfolio]; %store in the quality distribution
        qualpower_grid(1,1)=qualpower_grid(1,1)+qualpower_total_current; %store in the age-varieties distribution
        size_vec=[size_vec; qualpower_total_current]; %store in the size distribution
        jobchangelag_vec=[jobchangelag_vec; qualpower_total_current]; %store in the job flows distribution
        growthlag_vec=[growthlag_vec; 2]; %store in the growth distribution
        employment(1,2)=employment(1,2)+emp_current; %store in the employment distribution (by 4 dynamic groups)
        
        while exit==0 && age<N %for surviving firms
            state_full=[]; %store innovation outcomes for each variety
            
            if robustness~=5
                for i=1:n_current
                    state_full=[state_full; mnrnd(1,p_vec)]; %draw a random vector with the number of varieties in each of the p_vec states in the following period.
                end
            else %directed entrants model
                is_lowq=(qualpower_portfolio<=thresh_qual);
                for i=1:n_current
                    if is_lowq(i)==1 %apply different delta_e depending on quality of incumbent variety
                        state_full=[state_full; mnrnd(1,p_vec_lowq)]; 
                    else
                        state_full=[state_full; mnrnd(1,p_vec_highq)];
                    end
                end
            end
            
            state=sum(state_full,1); %sum outcomes for all varieties
            n_new=3*(sum(state(1:2)))+2*sum(state([3:5 7 8]))+sum(state([6 9:11])); %number of varieties in the following period
            
            if n_new>4*N %make sure code does not go out of the specified grid (very unlikely for sensible parameters)
                break
                display('too many varieties generated')
            end
            size_last=[size_last; size_vec(end)]; %store size in the previous period
            age_vec_last=[age_vec_last; age]; %store age in the previous period
            if n_new==0 %stop the path if a firm loses all varieties
                exit=1; %flag exit
                %Add to old employment share of exiters. Employment share needs to
                %be corrected by growth in aggregate employment. Older firms,
                %born amidst a smaller labor force, are overrepresented in
                %terms of employment share. Hence the division by
                %((1+kappa_i+kappa_e)^age) below.
                employment(2,1)=employment(2,1)+emp_current/((1+kappa_i+kappa_e)^age);
                exit1yr_vec=[exit1yr_vec; 1]; %record exit
                growthlag_vec=[growthlag_vec; -2]; %DHS growth of exiters is -2
                jobchangelag_vec=[jobchangelag_vec; size_vec(end)]; %job flows
                age_vecall=[age_vecall age+1]; %age
                JD_age(age+1)=JD_age(age+1)+emp_current; %add to JD
                
                
            else
                %correct relative innovation shocks for aggregate quality growth:
                qual_transit_exist=state_full(:,[1 2 4 5 7 8 10 11])/(1+gqpower);
                if model>1 %add Pareto step size
                    so_sigma=alpha^(sigma-1)*(1-rand(size(qual_transit_exist(:,[1 3 5 7])))).^(-(sigma-1)/theta);
                end
                qual_transit_exist(:,[1 3 5 7])=so_sigma.*qual_transit_exist(:,[1 3 5 7]); %add OI shocks
                exist_quals=sum(qual_transit_exist.*repmat(qualpower_portfolio,1,8),2); %apply shocks to existing varieties
                exist_quals(exist_quals==0)=[];
                contrib_growth=(1+gqpower)*sum(sum((so_sigma-1)./so_sigma.*qual_transit_exist(:,[1 3 5 7]).*...
                    repmat(qualpower_portfolio,1,4))); %contribution to growth from OI
                %generate CD shocks for initial varieties that lead to stealing
                %an extra variety:
                rnd_indeces_stolen=unidrnd(length_quals,1,sum(state(1:6)));
                if s_kappa==1
                    %generate NV shocks for initial varieties that lead to
                    %creating an extra variety:
                    rnd_indeces_created=unidrnd(length_quals,1,sum(state([1:3 7:9])));
                    %apply shocks to added varieties drawn from the existing distribution
                    added_quals=sq_rel.*qualpowerstore_vec_guess([rnd_indeces_stolen';rnd_indeces_created']);
                else
                    if model>1 %add Pareto step size
                        sq_rel=alpha^(sigma-1)*(1-rand(length(rnd_indeces_stolen),1)).^(-(sigma-1)/theta)/(1+gqpower);
                    end
                    %generate NV shocks for initial varieties that lead to
                    %creating an extra variety:
                    rnd_indeces_created=unidrnd(length_pool_new_var,1,sum(state([1:3 7:9])));
                    if sum(state(1:6))>0 %there is CD of other firms
                        %apply shocks to added varieties drawn from the existing distribution
                        added_quals=([sq_rel.*qualpowerstore_vec_guess(rnd_indeces_stolen);kappa_resc*pool_new_var(rnd_indeces_created')]);
                        contrib_growth=contrib_growth+sum([(sq_rel*(1+gqpower)-1).*qualpowerstore_vec_guess(rnd_indeces_stolen);...
                            kappa_resc*(1+gqpower)*pool_new_var(rnd_indeces_created')]); %contribution to growth from CD and OI
                    else
                        added_quals=kappa_resc*pool_new_var(rnd_indeces_created');
                        contrib_growth=contrib_growth+sum(added_quals); %contribution to growth from NV
                    end
                    
                end
                
                %store variety qualities:
                if isempty(added_quals)
                    qualpower_portfolio=exist_quals;
                else
                    qualpower_portfolio=[exist_quals; added_quals];
                end
                
                %Kill incumbent varieties below the OH threshold psi_abs
                OH_killed_inc=[OH_killed_inc; qualpower_portfolio(qualpower_portfolio<psi_abs)];
                n_new=n_new-length(qualpower_portfolio(qualpower_portfolio<psi_abs));
                %Check again if there is firm exit after OH costs are taken
                %into account
                if n_new==0 %stop the path if a firm loses all varieties
                    exit=1;
                    employment(2,1)=employment(2,1)+emp_current/((1+kappa_i+kappa_e)^age);
                    exit1yr_vec=[exit1yr_vec; 1];
                    growthlag_vec=[growthlag_vec; -2];
                    jobchangelag_vec=[jobchangelag_vec; size_vec(end)];
                    age_vecall=[age_vecall age+1];
                    JD_age(age+1)=JD_age(age+1)+emp_current;
                    
                else %store all relevant variables for the incumbent
                    %update for OH threshold:
                    surviving_indices=find(sum(state_full(:,[1 2 4 5 7 8 10 11]),2)>0); %varieties not lost
                    surviving_indices=surviving_indices(exist_quals>=psi_abs);
                    qualpower_portfolio=qualpower_portfolio(qualpower_portfolio>=psi_abs);
                    exist_quals=exist_quals(exist_quals>=psi_abs);
                    added_quals=added_quals(added_quals>=psi_abs);
                    
                    %store geometric sum of variety qualities:
                    if isempty(surviving_indices)==1
                        qualpower_total_new=sum(added_quals);
                    else
                        qualpower_total_new=sum([exist_quals; added_quals]);
                    end
                    contrib_growth_age(age+1)=contrib_growth_age(age+1)+contrib_growth; %contribution to growth by age
                    emp_new=qualpower_total_new; %employment in the current period
                    varietyall_vec=[varietyall_vec n_new]; %number of varieties
                    age_vec=[age_vec age+1]; %firm age
                    age_vecall=[age_vecall age+1]; %firm age
                    qualpowerstore_vec=[qualpowerstore_vec; qualpower_portfolio]; %keep storing in the quality distribution
                    age_var_vec=[age_var_vec; age*ones(n_new,1)]; %age of varieties
                    dens_grid(age+1,n_new)=dens_grid(age+1,n_new)+1; %store density in age-varieties distribution
                    qualpower_grid(age+1,n_new)=qualpower_grid(age+1,n_new)+qualpower_total_new; %store employment in age-varieties distribution
                    size_vec=[size_vec; qualpower_total_new]; %keep storing in the size distribution
                    growthlag_vec=[growthlag_vec; diff(size_vec(end-1:end))/mean(size_vec(end-1:end))]; %DHS growth distribution
                    jobchangelag_vec=[jobchangelag_vec; diff(size_vec(end-1:end))]; %job flows
                    JC_age(age+1)=JC_age(age+1)+subplus(jobchangelag_vec(end)); %add to JC by age if JC>0
                    JD_age(age+1)=JD_age(age+1)+subplus(-jobchangelag_vec(end)); %add to JD by age if JD>0
                    exit1yr_vec=[exit1yr_vec; 0]; %record lack of exit
                    
                    %add to employment distribution for incumbent firms destroying and creating employment
                    if emp_current<emp_new %firms destroying employment
                        %need to correct for aggregate employment growth
                        employment(3,1)=employment(3,1)+emp_current/((1+kappa_i+kappa_e)^age); %add to old employment share
                        employment(3,2)=employment(3,2)+emp_new/((1+kappa_i+kappa_e)^age); %add to new employment share
                    else %firms creating employment
                        %need to correct for aggregate employment growth
                        employment(4,1)=employment(4,1)+emp_current/((1+kappa_i+kappa_e)^age); %add to old employment share
                        employment(4,2)=employment(4,2)+emp_new/((1+kappa_i+kappa_e)^age); %add to new employment share
                    end
                    
                    emp_current=emp_new; %update current employment for next period
                end
            end
            age=age+1; %update age (age is expressed in 5-year periods)
            n_current=n_new; %update current number of varieties for next period
        end
        rep=rep+1; %move to next entrant
    end
end

%% Compute Aggregate Moments

% Correcting density for aggregate employment growth
%We need this when aggregating firms of different ages, as firms born in a
%more distant past, i.e. within a smaller labor force, would otherwise be overrepresented
newvar_correction   = [(1+kappa_e+kappa_i).^(0:N-1)]'; %vector with cumulative growth in varieties
newvar_correction_weights = (sum(1./newvar_correction)./newvar_correction); %normalize discount weights to sum to 1
%correct aggregation grids with weights for each age in the age-varieties grid:
dens_grid_corrected = dens_grid./repmat(newvar_correction,1,size(dens_grid,2));
qualpower_grid_corrected = qualpower_grid./repmat(newvar_correction,1,size(dens_grid,2));
contrib_growth_age_corrected = contrib_growth_age./newvar_correction;
JC_age_corrected = JC_age./newvar_correction;
JD_age_corrected = JD_age./newvar_correction;

%employment (equal to market share) by age:
mshare_5=sum(employment(1,2))/sum(employment(:,2)); %share of entrants
mshare_5=[mshare_5;1-mshare_5];

%exit by age
exit_ageT=[];
for i=1:N-1
    exit_ageT = [exit_ageT; 1/5*(1-sum(dens_grid(i+1,:))/sum(dens_grid(i,:)))]; %annualized exit rate
end
exit_ageT(isnan(exit_ageT))=0; %for ages with no firms, assume exit is 0
exit_age=[exit_ageT(1); [exit_ageT; 1]'*sum(dens_grid_corrected,2)/sum(sum(dens_grid_corrected,2))]; %for young and old

%size by age:
aver_size_age=sum(qualpower_grid_corrected,2)./sum(dens_grid_corrected,2);
aver_size_age5=[aver_size_age(1); sum(sum(qualpower_grid_corrected(2:end,:),2))/sum(sum(dens_grid_corrected(2:end,:),2))]; %for entrants and incumbents
aver_size_model=sum(sum(qualpower_grid_corrected))/sum(sum(dens_grid_corrected)); %overall average size

% JD and JC flows (a la DHS):
createt_dest=sum([subplus(employment(:,2)-employment(:,1)) subplus(-employment(:,2)+employment(:,1))])'/mean(sum(employment));

%Apply correction weights (for aggr. empl. growth) to vectors for different
%groups of firms
newvar_correction_weights_long=newvar_correction_weights(age_vec); %existing firms
newvar_correction_weights_alllong=newvar_correction_weights(age_vecall); %all firms
newvar_correction_weights_last=newvar_correction_weights(age_vec_last); %last year firms

%DHS job flows by bins:
bins_halt=-2.05:0.05:2.05; %employment growth bins
growth_halt=[];
for i=1:length(bins_halt)-1 %compute contribution to JD and JC of each growth bin
    if i==2
        growth_halt=[growth_halt; sum(newvar_correction_weights_alllong(logical((growthlag_vec>bins_halt(i)).*(growthlag_vec<bins_halt(i+1))))'*...
            abs(jobchangelag_vec(logical((growthlag_vec>bins_halt(i)).*(growthlag_vec<bins_halt(i+1))))))];
    else
        growth_halt=[growth_halt; sum(newvar_correction_weights_alllong(logical((growthlag_vec>=bins_halt(i)).*(growthlag_vec<bins_halt(i+1))))'*...
            abs(jobchangelag_vec(logical((growthlag_vec>=bins_halt(i)).*(growthlag_vec<bins_halt(i+1))))))];
    end
end
%normalize to 100 percent:
growth_halt=100*growth_halt./[repmat(sum(growth_halt(1:end/2)),length(growth_halt)/2,1); repmat(sum(growth_halt(end/2+1:end)),length(growth_halt)/2,1)];

%Exit probability by size bin

% Measures by ten bins:
bin10_size=[0 5 10 20 50 100 250 500 1000 5000 1e30]; %bins in the data (num. of employees)
bin10_size=aver_size_model*bin10_size/data_mean_size_v2; %normalize for mean size in simulation
exit_size_level=zeros(length(bin10_size)-1,1);
for i=1:length(bin10_size)-1
    exit_size_level(i)=1/5*mean(newvar_correction_weights_last(logical((size_last>=bin10_size(i)).*(size_last<bin10_size(i+1))))'...
        *exit1yr_vec(logical((size_last>=bin10_size(i)).*(size_last<bin10_size(i+1))))...
        /sum(newvar_correction_weights_last(logical((size_last>=bin10_size(i)).*(size_last<bin10_size(i+1))))));   %annualized exit rates
end

%grouping all firms with 500+ employees
exit_size500_level=[exit_size_level(1:7);...
    1/5*mean(newvar_correction_weights_last(size_last>=bin10_size(8))'...
    *exit1yr_vec(size_last>=bin10_size(8))...
    /sum(newvar_correction_weights_last(size_last>=bin10_size(8))))];

%Exit above and below mean size
exit_size2_level=zeros(2,1);
exit_size2_level(1)=1/5*mean((newvar_correction_weights_last(size_last<aver_size_model))'...
    *exit1yr_vec(size_last<aver_size_model)/sum(newvar_correction_weights_last(size_last<aver_size_model)));
exit_size2_level(2)=1/5*mean((newvar_correction_weights_last(size_last>=aver_size_model))'...
    *exit1yr_vec(size_last>=aver_size_model)/sum(newvar_correction_weights_last(size_last>=aver_size_model)));

%average num. of varieties by size
variety_size_level=zeros(length(bin10_size)-1,1);
for i=1:length(bin10_size)-1
    variety_size_level(i)=mean(newvar_correction_weights_long(logical((size_vec>=bin10_size(i)).*(size_vec<bin10_size(i+1))))'...
        *varietyall_vec(logical((size_vec>=bin10_size(i)).*(size_vec<bin10_size(i+1))))'...
        /sum(newvar_correction_weights_long(logical((size_vec>=bin10_size(i)).*(size_vec<bin10_size(i+1))))));
end


%standard deviation log size all
std_logsize=sqrt(newvar_correction_weights_long'*(log(size_vec).^2)/sum(newvar_correction_weights_long)-...
    (newvar_correction_weights_long'*log(size_vec)/sum(newvar_correction_weights_long))^2);

%average quality of incumbent OH killed varieties
psi_mean=mean(OH_killed_inc);

toc
%Correct representativity of quality and variety distribution for agg. empl. growth
%(qualities of older firms would be overrepresented otherwise)
qualpowerstore_vec_corrected=[];
variety_vec_corrected=[];
for i=1:max(age_var_vec)
    vars_age=qualpowerstore_vec(age_var_vec==i); %store varieties of each age
    
    %find number of random draws to add to have representative
    %sample:
    n_vars_age=[varietyall_vec(age_vec==i)]';
    if kappa_e+kappa_i<0.13
        num_selected=floor(length(vars_age)*((1+kappa_e+kappa_i)^(max(age_var_vec)-i)-1));
    else %approximate old age to cosntant discount rate in order to avoid a huge vector for small numbers of varieties
        num_selected=floor(length(vars_age)*((1+kappa_e+kappa_i)^(max(age_var_vec)/2-i)-1));
    end
    
    if num_selected==0 %keep original sample
        qualpowerstore_vec_corrected=[qualpowerstore_vec_corrected; vars_age];
        variety_vec_corrected=[variety_vec_corrected; n_vars_age];
        
    else %keep original sample and add random draws from the same sample
        qualpowerstore_vec_corrected=[qualpowerstore_vec_corrected;...
            vars_age;vars_age(ceil(length(vars_age)*rand(num_selected,1)))];
        variety_vec_corrected=[variety_vec_corrected;...
            n_vars_age;n_vars_age(ceil(length(n_vars_age)*rand(num_selected,1)))];
    end
end
qualpowerstore_vec=qualpowerstore_vec_corrected; %store corrected quality distribution
toc
